#! /bin/sh
#
#+
#
# NAME
# ====
#
# elogd.sh - edit the most recent ${VARAMMA_LOG}/action.log.YYYY-MM-DDTHH:MM:SSZ
#
# SYNOPSIS
# ========
#
# ::
#
#  $ elogd.sh action
#
#
# DESCRIPTION
# ===========
#
# ``elogd.sh`` launch ${EDITOR} on the most recent release of ${VARAMMA_LOG}/action.log.YYYY-MM-DDTHH:MM:SSZ.
#
#
# SEE ALSO
# ========
#
# varamma_profile.sh_
#
# .. _varamma_profile.sh : varamma_profile.sh.html
#
# dlogd.sh_
#
# .. _dlogd.sh : dlogd.sh.html
#
# plogd.sh_
#
# .. _plogd.sh : plogd.sh.html
#
# tlogd.sh_
#
# .. _tlogd.sh : tlogd.sh.html
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/varamma/varamma_ws/src/elogd.sh sur aedon.locean-ipsl.upmc.fr
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 2008-11-26T11:26:40Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
#
set -u
system=$(uname)
case "${system}" in
AIX|IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
command=$(basename ${0})
#
if [ ! "${EDITOR}" ]
then
 echo " ${command} : eee : EDITOR undefined" >&2
 exit 1
fi
if [ "${1}" = "" ]
then
 echo "${command} : eee : 1st parameter missing" >&2
 exit 1
fi
#
# check for ${VARAMMA_LOG} definition
if [ "${VARAMMA_LOG}" = "" ]
then
 echo " eee : \${VARAMMA_LOG} not defined"
 exit 1
fi
#
# check for ${VARAMMA_LOG} existence
if [ ! -d ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not found"
 exit 1
fi
#
# check for permission access on VARAMMA_LOG
if [ ! -x ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not reachable"
 exit 1
fi
#
log=$(find ${VARAMMA_LOG} -name "${1}.log.????-??-??T??:??:??Z" | sort | \
tail -n 1)
tmp=${?}
if [ ${tmp} -eq 0 ]
then
 if [ "${log}" = "" ]
 then
  echo "${command} : eee : no release of ${VARAMMA_LOG}/${1}.log" >&2
  exit 1
 else
  # edit
  ${EDITOR} ${log}
  exit 0
 fi
else
 exit 1
fi
