#! /bin/sh
#
#+
#
# NAME
# ====
#
# tlogd.sh -  shows the most recent release of ${VARAMMA_LOG}/<action>.log.YYYY-MM-DDTHH:MM:SSZ
#
# SYNOPSIS
# ========
#
# ::
#
#  $ tlogd.sh action
#
#
# DESCRIPTION
# ===========
#
# ``tlogd.sh`` shows the most recent release of ${VARAMMA_LOG}/action.log.YYYY-MM-DDTHH:MM:SSZ.
#
#
# SEE ALSO
# ========
#
# varamma_profile.sh_
#
# .. _varamma_profile.sh : varamma_profile.sh.html
#
# dlogd.sh_
#
# .. _dlogd.sh : dlogd.sh.html
#
# elogd.sh_
#
# .. _elogd.sh : elogd.sh.html
#
# plogd.sh_
#
# .. _plogd.sh : plogd.sh.html
#
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/varamma/varamma_ws/src/tlogd.sh sur aedon.locean-ipsl.upmc.fr
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 2008-11-26T11:26:40Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
#
set -u
system=$(uname)
case "${system}" in
AIX|IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
#
command=$(basename ${0})
#
if [ "${1}" = "" ]
then
 echo "${command} : eee : 1st parameter missing" >&2
 exit 1
fi
# check for ${VARAMMA_LOG} definition
if [ "${VARAMMA_LOG}" = "" ]
then
 echo " eee : \${VARAMMA_LOG} not defined"
 exit 1
fi
#
# check for ${VARAMMA_LOG} existence
if [ ! -d ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not found"
 exit 1
fi
#
# check for permission access on VARAMMA_LOG
if [ ! -x ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not reachable"
 exit 1
fi
#
log=$(find ${VARAMMA_LOG} -name "${1}.log.????-??-??T??:??:??Z" 2> /dev/null | sort | \
tail -n 1)
tmp=${?}
if [ ${tmp} -eq 0 ]
then
 if [ "${log}" = "" ]
 then
  echo "${command} : eee : no release of ${VARAMMA_LOG}/${1}.log" >&2
  exit 1
 else
  more ${log}
  exit 0
 fi
else
 exit 1
fi
